..
    Copyright (C) 2022 Graz University of Technology.

    invenio-workflows-tugraz is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v0.1.14 (release 2023-05-11)




Version v0.1.13 (release 2023-05-10)

- theses: apply requested marc21 field changes
- fix: date for status


Version v0.1.12 (release 2023-05-10)

- fix: the crap from last commit


Version v0.1.11 (release 2023-05-10)

- fix: date and format where not compatible


Version v0.1.10 (release 2023-05-10)

- fix: used wrong date format


Version v0.1.9 (release 2023-05-10)

- theses: apply marc21 request changes


Version v0.1.8 (release 2023-04-25)

- theses: add necessary need to import


Version v0.1.7 (release 2023-01-26)

- theses: change alma import size
- theses: change import start date


Version v0.1.6 (release 2023-01-23)

- modification: create an endpoint for theses records


Version v0.1.5 (release 2023-01-23)

- fix: return value of import_func
- fix: wrong alias name


Version v0.1.4 (release 2023-01-20)

- theses fix: play safe with real data


Version v0.1.3 (release 2023-01-20)

- theses: mapping change


Version v0.1.2 (release 2023-01-20)

- fix: remove print


Version v0.1.1 (release 2023-01-18)

- theses: convert abstract and keywords


Version v0.1.0 (release 2023-01-18)




